# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added

## [1.0.0] - 2025-03-26

### Breaking Changes
- Bump version to 1.0.0 for stable API release

### Changed
- Renamed `postgres.py` to `pgjinja.py` for better module name consistency

## [0.1.0] - 2025-03-26

### Added
- Initial project structure
- Basic functionality
- Initial release

[Unreleased]: https://github.com/tungph/pgjinja/compare/v1.0.0...HEAD
[1.0.0]: https://github.com/tungph/pgjinja/compare/v0.1.0...v1.0.0
[0.1.0]: https://github.com/tungph/pgjinja/releases/tag/v0.1.0

